/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.remote.jaxrs.whiteboard.jaxb.json.internal;

import com.liferay.portal.kernel.util.HashMapDictionaryBuilder;

import java.util.Map;

import javax.ws.rs.core.MediaType;
import javax.ws.rs.ext.MessageBodyReader;
import javax.ws.rs.ext.MessageBodyWriter;

import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceRegistration;
import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.ConfigurationPolicy;
import org.osgi.service.component.annotations.Deactivate;
import org.osgi.service.jaxrs.whiteboard.JaxrsWhiteboardConstants;

/**
 * @author Shuyang Zhou
 */
@Component(
	configurationPid = "org.apache.aries.jax.rs.jackson",
	configurationPolicy = ConfigurationPolicy.REQUIRE,
	property = {
		JaxrsWhiteboardConstants.JAX_RS_EXTENSION + "=true",
		JaxrsWhiteboardConstants.JAX_RS_MEDIA_TYPE + "=" + MediaType.APPLICATION_JSON,
		JaxrsWhiteboardConstants.JAX_RS_NAME + "=jaxb-json",
		"service.ranking:Integer=" + Integer.MIN_VALUE
	},
	service = {}
)
public class JacksonJsonProviderRegistrator {

	@Activate
	protected void activate(
		BundleContext bundleContext, Map<String, Object> properties) {

		_serviceRegistration = bundleContext.registerService(
			new String[] {
				MessageBodyReader.class.getName(),
				MessageBodyWriter.class.getName()
			},
			new JacksonJsonProviderPrototypeServiceFactory(),
			HashMapDictionaryBuilder.create(
				properties
			).put(
				"jackson.jaxb.version",
				String.valueOf(
					com.fasterxml.jackson.module.jaxb.PackageVersion.VERSION)
			).put(
				"jackson.jaxrs.json.version",
				String.valueOf(
					com.fasterxml.jackson.jaxrs.json.PackageVersion.VERSION)
			).build());
	}

	@Deactivate
	protected void deactivate() {
		_serviceRegistration.unregister();
	}

	private ServiceRegistration<?> _serviceRegistration;

}